<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['%d association'] = '%d 相關';
$lang['%d associations'] = '%d 相關';
$lang['%d album including'] = '%d 相冊包含中';
$lang['%d albums including'] = '%d 相冊包含中';
$lang['%d physical'] = '物理 %d';
$lang['%d physical'] = '物理 %d ';
$lang[' and %d virtual'] = ' 和 虛擬 %d ';
$lang[' and %d virtual'] = ' 和 虛擬 %d ';
$lang['%d album moved'] = '%d 相冊已移動';
$lang['%d albums moved'] = '%d 相冊已移動';
$lang['%d group'] = '%d 組';
$lang['%d groups'] = '%d 組';
$lang['%d member'] = '%d 成員';
$lang['%d members'] = '%d 成員';
$lang['%d tag'] = '%d 標籤';
$lang['%d tags'] = '%d 標籤';
$lang['%d user comment rejected'] = '%d 用戶評論被刪除';
$lang['%d user comments rejected'] = '%d 用戶評論被刪除';
$lang['%d user comment validated'] = '%d 用戶評論已確認有效';
$lang['%d user comments validated'] = '%d 用戶評論已確認有效';
$lang['%d user deleted'] = '%d 用戶已刪除';
$lang['%d users deleted'] = '%d 用戶已刪除';
$lang['%d user'] = '%d 用戶';
$lang['%d users'] = '%d 用戶';
$lang['%d waiting for validation'] = '%d 等待確認有效';
$lang['Actions'] = '實施';
$lang['Activate'] = '激活';
$lang['Add/delete a permalink'] = '增加/刪除一個固定鏈接';
$lang['Add a tag'] = '增加標籤';
$lang['Add a user'] = '增加用戶';
$lang['Add group'] = '增加組';
$lang['Add'] = '增加';
$lang['Allow user registration'] = '允許用戶註冊';
$lang['Apply to sub-albums'] = '應用到子相冊';
$lang['Associated'] = '關聯於';
$lang['Batch management'] = '分批管理';
$lang['Caddie management'] = '購物籃管理';
$lang['Caddie'] = '購物籃';
$lang['Albums authorized thanks to group associations'] = '相冊組織授權感謝協會';
$lang['Album manual order was saved'] = '相冊手工排序已保存';
$lang['Check for upgrade failed for unknown reasons.'] = '因未知原因導致更新檢測失敗.';
$lang['Check for upgrade'] = '檢測更新';
$lang['Comments for all'] = '對所有成員進行評論';
$lang['Current name'] = '現用名';
$lang['Database'] = '數據庫';
$lang['Deactivate'] = '註銷';
$lang['Delete Representant'] = '刪除代理人';
$lang['Delete selected tags'] = '刪除所選標籤';
$lang['Delete selected users'] = '刪除所選用戶';
$lang['Deletions'] = '刪除';
$lang['Deny selected groups'] = '所選組禁止訪問';
$lang['Deny selected users'] = '所選用戶禁止訪問';
$lang['Description'] = '描述';
$lang['Display options'] = '顯示選項';
$lang['Dissociated'] = '取消聯繫';
$lang['Does not represent'] = '不需描繪';
$lang['Edit selected tags'] = '編輯所選標籤';
$lang['Edit tags'] = '編輯標籤';
$lang['Email admins when a new user registers'] = '一旦用戶註冊就通知管理員';
$lang['Email admins when a valid comment is entered'] = '當用戶發表評論時就通知管理員';
$lang['Email admins when a comment requires validation'] = '當用戶要求確認他的評論時通知管理員';
$lang['Environment'] = '環境';
$lang['Form'] = '表單';
$lang['Gallery title'] = '圖庫標題';
$lang['Grant selected groups'] = '對所選組授權';
$lang['Grant selected users'] = '對所選用戶授權';
$lang['Group name'] = '組名';
$lang['Groups'] = '組';
$lang['Guests'] = '遊客';
$lang['History'] = '歷史';
$lang['Informations'] = '信息';
$lang['Install'] = '安裝';
$lang['Link all album photos to a new album'] = '鏈接所有相冊的相片到新的相冊';
$lang['Link all album photos to some existing albums'] = '鏈接所有相冊的相片到現有的相冊';
$lang['Linked albums'] = '已鏈接相冊';
$lang['Lock gallery'] = '凍結圖庫';
$lang['Maintenance'] = '維護';
$lang['Edit album permissions'] = '管理相冊的權限';
$lang['Manage permissions for group "%s"'] = '對組 "%s" 進行權限管理';
$lang['Manage permissions for user "%s"'] = '對用戶 "%s" 進行權限管理';
$lang['Manage tags'] = '標籤管理';
$lang['Members'] = '成員';
$lang['Metadata synchronized from file'] = '對文件進行元數據同步';
$lang['Move albums'] = '移動相冊';
$lang['Move'] = '移動';
$lang['Name'] = '名字';
$lang['New name'] = '新名';
$lang['New parent album'] = '新的父相冊';
$lang['New tag'] = '新標籤';
$lang['Number of comments per page'] = '每頁評論數';
$lang['Number of rates'] = '投票數';
$lang['Number of thumbnails to create'] = '縮略圖數';
$lang['Only private albums are listed'] = '只列出私有相冊';
$lang['Operating system'] = '操作系統';
$lang['Options'] = '選項';
$lang['Other private albums'] = '其他私有相冊';
$lang['Page banner'] = '頁標語';
$lang['Parent album'] = '父相冊';
$lang['Path'] = '路徑';
$lang['Permalink'] = '固定鏈接';
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = '固定鏈接 %s 已被 %s 相冊使用了。請先從固定鏈接歷史記錄刪除。';
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = '固定鏈接中包含了非法字符（"a-zA-Z0-9", "-", "_" ou "/"）. 禁止使用數字和以"-"開頭後面緊跟數字';
$lang['Permalink %s is already used by album %s'] = '固定鏈接 %s 已被 %s 相冊使用了';
$lang['Permalink history'] = '固定鏈接歷史記錄';
$lang['Permalinks'] = '固定鏈接';
$lang['Permission denied'] = '禁止訪問';
$lang['Permission granted thanks to a group'] = '同組成員可以訪問授權類';
$lang['Permission granted'] = '允許訪問';
$lang['Photo informations updated'] = '圖片更新信息';
$lang['Plugins'] = '插件';
$lang['Position'] = '位置';
$lang['Preferences'] = '個人偏好';
$lang['Properties'] = '屬性';
$lang['Random photo'] = '隨機';
$lang['Rate date'] = '投票日期';
$lang['Rating by guests'] = '遊客投票數';
$lang['Rating'] = '投票';
$lang['Reject'] = '取消';
$lang['Representant'] = '代理人';
$lang['Representation of albums'] = '相冊代表';
$lang['Representative'] = '代理人';
$lang['Represents'] = '代理';
$lang['Save order'] = '保存排序';
$lang['Save to permalink history'] = '保存到固定鏈接的歷史記錄中';
$lang['Select at least one album'] = '選擇最後一個相冊';
$lang['Select at least one photo'] = '至少選中一張圖片';
$lang['Select at least one user'] = '至少選中一個用戶';
$lang['Show info'] = '顯示所有信息';
$lang['Site manager'] = '網管';
$lang['Status'] = '狀態';
$lang['Statistics'] = '統計';
$lang['Storage album'] = '存儲相冊';
$lang['Sum of rates'] = '總投票分';
$lang['Tag "%s" already exists'] = '標籤 "%s" 已存在';
$lang['Tag "%s" was added'] = '標籤 "%s" 已加入';
$lang['Tag selection'] = '標籤選擇';
$lang['The %d following tags were deleted'] = '下面標籤 %d 已刪除';
$lang['Unable to check for upgrade.'] = '不能檢測更新.';
$lang['Uninstall'] = '卸載';
$lang['Use the default photo sort order (defined in the configuration file)']='使用默認圖片排序(在配置文件中定義)';
$lang['User comments validation'] = '確認用戶評論';
$lang['Users'] = '用戶';
$lang['Validate'] = '確認';
$lang['Validation'] = '確認';
$lang['Version'] = '版本';
$lang['Virtual albums to move'] = '移動虛擬相冊';
$lang['Virtual album name'] = '虛擬相冊名稱';
$lang['Webmaster cannot be deleted'] = '不能刪除網管帳戶';
$lang['You are running on development sources, no check possible.'] = '你運行的是源碼開發版本, 不能檢測最新版.';
$lang['You cannot delete your account'] = "你不能刪除自己本身帳號";
$lang['You cannot move an album in its own sub album'] = '您不能將一個相冊移動到其子相冊裡';
$lang['You need to confirm deletion'] = '你必須確認刪除操作';
$lang['add tags'] = '增加標籤';
$lang['Associate to album'] = '聯合到相冊';
$lang['associate to group'] = '關聯到組';
$lang['Authorized'] = '授權';
$lang['Add a virtual album'] = '添加一個虛擬相冊';
$lang['Authorize users to add comments on selected albums'] = '讓用戶可在所選相冊裡發表評論';
$lang['The name of an album must not be empty'] = '相冊名稱不能為空';
$lang['Lock albums'] = '鎖定相冊';
$lang['Private'] = '私有相冊';
$lang['Public'] = '公共相冊';
$lang['Find a new representant by random'] = '隨機尋找代理人';
$lang['Public / Private'] = '公有 / 私有';
$lang['Manage authorizations for selected albums'] = '管理所選相冊的授權';
$lang['Virtual album added'] = '虛擬相冊已添加';
$lang['Virtual album deleted'] = '虛擬相冊已刪除';
$lang['Access type'] = '權限類型';
$lang['Comments'] = '評論';
$lang['Information data registered in database'] = '信息已保存到數據庫中';
$lang['Default display'] = '默認顯示';
$lang['The gallery URL is not valid.'] = '圖庫地址不合法.';
$lang['Main'] = '主頁';
$lang['The number of comments a page must be between 5 and 50 included.'] = '每頁用戶評論數必須在5和50之間.';
$lang['Configuration'] = '設置';
$lang['confirm'] = '設置';
$lang['Date'] = '日期';
$lang['delete album'] = '刪除相冊';
$lang['Dissociate from album'] = '從相冊裡分離';
$lang['dissociate from group'] = '取消組關聯';
$lang['edit album permissions'] = '修改相冊權限';
$lang['Album updated successfully'] = '相冊信息已上傳成功.';
$lang['photos per page'] = '每頁圖片';
$lang['High definition enabled'] = '激活高清功能';
$lang['File'] = '文件';
$lang['Filesize'] = '大小';
$lang['first photo added on %s'] = '於 %s 上傳了第一幅圖';
$lang['Forbidden'] = '禁止';
$lang['global mode'] = '全局模式';
$lang['group "%s" added'] = '增加 "%s" 組';
$lang['group "%s" deleted'] = '刪除 "%s" 組';
$lang['group "%s" updated'] = '更新 "%s" 組';
$lang['group'] = '組';
$lang['The name of a group must not contain " or \' or be empty.'] = '組名不能包含 " 或 \' 並不能為空.';
$lang['This name is already used by another group.'] = '組名已存在.';
$lang['High definition'] = '高清';
$lang['jump to album'] = '跳到相冊';
$lang['jump to photo'] = '跳轉到圖';
$lang['leave'] = '開鎖';
$lang['Lock'] = '上鎖';
$lang['Locked'] = '鎖定';
$lang['manage album photos'] = '管理相冊裡的相片';
$lang['manage sub-albums'] = '管理子相冊';
$lang['Manage'] = '管理';
$lang['maximum height'] = '最高高度';
$lang['maximum width'] = '最長長度';
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = '已超過執行時間, 處理還需時間[估計時間: %d 秒].';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = '已超過執行時間, 處理還需時間[估計時間: %d 秒].';
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = '由於發送用戶列表的準備時間受限制,其餘用戶將不被列出.';
$lang['Time to send mail is limited. Others mails are skipped.'] = '發送郵件時間有限,其餘郵件被忽略.';
$lang['To send ?'] = '發送?';
$lang['Last send'] = '最後一次發送';
$lang['email'] = '郵件';
$lang['User'] = '用戶';
$lang['Complementary mail content'] = '郵件附件';
$lang['See you soon,'] = '再見,';
$lang['Go to'] = '轉至 ';
$lang['Hello'] = '你好 ';
$lang['New photos were added'] = '加入一些新圖片';
$lang['on'] = '時間: ';
$lang['between'] = '時間: ';
$lang['and'] = ' 至 ';
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = '網管開通了你的郵件通知功能.';
$lang['You have subscribed to receiving notifications by mail.'] = '你開通了郵件通知功能.';
$lang['To subscribe'] = '註冊新用戶';
$lang['If you encounter problems or have any question, please send a message to'] = '如有遇到故障或問題,請發郵件至 ';
$lang['[NBM] Problems or questions'] = '[NBM] 故障或問題';
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = '網管取消了你的郵件通知功能.';
$lang['You have unsubscribed from receiving notifications by mail.'] = '你取消了你的郵件通知功能.';
$lang[', click on'] = ', 請點擊 ';
$lang['To unsubscribe'] = '註銷';
$lang['With blank value, gallery title will be used'] = '圖庫標題允許為空';
$lang['Notification'] = '通知';
$lang['Error when sending email to %s [%s].'] = '發送郵件 給 %s [%s] 是發生了錯誤.';
$lang['Mail sent to %s [%s].'] = '已發送至 %s [%s].';
$lang['%d mail was sent.'] = '%s 郵件已發送.';
$lang['%d mails were sent.'] = '%s 郵件已發送.';
$lang['%d mail was not sent.'] = '%s 郵件未被發送.';
$lang['%d mails were not sent.'] = '%s 郵件未被發送.';
$lang['No mail to send.'] = '沒有郵件要發送.';
$lang['There is no available subscribers to mail.'] = '沒有用戶需要郵件通知.';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = '只有當有新圖片時,才能使用用戶郵件通知功能.';
$lang['Anyway only webmasters can see this tab and never administrators.'] = '任何人都不能使用此標籤(網管除外).';
$lang['No user to send notifications by mail.'] = '沒有郵件通知用戶.';
$lang['New photos added'] = '新圖片已加入';
$lang['Subscribe to notification by mail'] = '註冊郵件通知功能';
$lang['Unsubscribe from notification by mail'] = '註銷郵件通知功能';
$lang['Parameter'] = '設置';
$lang['Continue processing treatment'] = '正在繼續處理中...';
$lang['Complementary mail content'] = '郵件附加內容';
$lang['Add detailed content'] = '增加細節內容';
$lang['Send mail as'] = '發送郵件作為';
$lang['Send mail to users'] = '給用戶發送郵件';
$lang['Send'] = '發送';
$lang['Options'] = '選項';
$lang['Subscribed'] = '已註冊';
$lang['Subscribe'] = '註冊';
$lang['Parameters'] = '設置參數';
$lang['Select recipients'] = '選擇接受郵件用戶';
$lang['Subscribe/unsubscribe users'] = '註冊/註銷用戶';
$lang['Unsubscribed'] = '已註銷';
$lang['%d parameter was updated.'] = '%d 參數已更新.';
$lang['%d parameters were updated.'] = '%d 等參數已更新.';
$lang['%d user was not updated.'] = '%d 用戶沒有被更新.';
$lang['%d users were not updated.'] = '%d 等用戶沒有被更新.';
$lang['User %s [%s] was removed from the subscription list.'] = '用戶 %s [%s] 從註冊名單中刪除.';
$lang['User %s [%s] was added to the subscription list.'] = '用戶 %s [%s] 加入到註冊名單中.';
$lang['%d user was updated.'] = '%d 用戶已更新.';
$lang['%d users were updated.'] = '%d 等用戶已更新.';
$lang['User %s [%s] was not removed from the subscription list.'] = '用戶 %s [%s] 沒有從註冊名單中刪除.';
$lang['User %s [%s] was not added to the subscription list.'] = '用戶 %s [%s] 沒有加到註冊名當中.';
$lang['User %s [%s] added.'] = '用戶 %s [%s] 已加入.';
$lang['Warning: subscribing or unsubscribing will send mails to users'] = '注意, 註冊或註銷都會給相關用戶發送郵件';
$lang['Send mail on HTML format'] = '以HTML格式發送郵件';
$lang['Include display of recent photos grouped by dates'] = '包括顯示最近按日期分組的圖片';
$lang['Available only with HTML format'] = '只能以HTML格式';
$lang['no write access'] = '不能寫入';
$lang['Permissions'] = '權限';
$lang['private'] = '私有';
$lang['public'] = '公有';
$lang['Purge never used notification feeds'] = '清除從沒使用過的通知回饋';
$lang['Purge sessions'] = '清除會話';
$lang['randomly represented'] = '隨機顯示';
$lang['registration date'] = '保存日期';
$lang['clean'] = '清除';
$lang['remove remote listing.xml file'] = '刪除遠端文件listing.xml';
$lang['generate listing'] = '創建列表';
$lang['generate file listing.xml on remote site'] = '創建遠端listing.xml文件';
$lang['Create this site'] = '創建網站';
$lang['A local listing.xml file has been found for'] = '發現本地文件listing.xml';
$lang['read local listing.xml and update'] = '讀本地文件listing.xml並更新';
$lang['test'] = '測試';
$lang['test this remote site'] = '測試遠端站點';
$lang['remove tags'] = '刪除所有標籤';
$lang['Repair and optimize database'] = '修復和優化數據庫';
$lang['selection'] = '選擇';
$lang['set to'] = '設置為';
$lang['singly represented'] = '固定顯示';
$lang['This site already exists'] = '此站點已存在';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = '新建遠端站點 : (在create_listing_file.php文件中給出url地址)';
$lang['created'] = '已創建';
$lang['delete'] = '刪除';
$lang['delete this site and all its attached elements'] = '刪除此站點和與其相關聯的所有信息';
$lang['an error happened'] = '發生錯誤';
$lang['file create_listing_file.php on remote site was not found'] = '在遠端站點中未發現create_listing_file.php文件';
$lang['Local'] = '本地';
$lang['Remote'] = '遠端';
$lang['synchronize'] = '同步';
$lang['update the database from files'] = '根據文件對數據庫進行更新';
$lang['status'] = '狀態';
$lang['Directory'] = '文件夾';
$lang['sub-albums'] = '子相冊';
$lang['synchronize metadata'] = '同步元數據';
$lang['target'] = '目標';
$lang['Thumbnail'] = '縮略圖';
$lang['title'] = '標題';
$lang['Album list management'] = '相冊管理';
$lang['Piwigo configuration'] = '配置Piwigo';
$lang['Edit album'] = '修改一個相冊';
$lang['Group management'] = '組管理';
$lang['User list'] = '用戶名單';
$lang['Edit photo information'] = '修改圖片信息';
$lang['Thumbnail creation'] = '創建縮略圖';
$lang['Database synchronization with files'] = '根據文件來同步數據庫';
$lang['all'] = '所有';
$lang['photos without thumbnail (jpeg and png only)'] = '沒有縮略圖的圖片 (只有jpeg和png)';
$lang['height must be a number superior to'] = '圖片高度必須超過(整數)';
$lang['width must be a number superior to'] = '圖片長度必須超過(整數)';
$lang['for the file format'] = '對於文件格式';
$lang['No missing thumbnail'] = '沒有丟失縮略圖';
$lang['Photo unreachable or no support'] = '不支持圖片格式或無法顯示';
$lang['GD version'] = 'GD版';
$lang['Miniaturization parameters'] = '縮略圖參數';
$lang['generated in'] = '產生於';
$lang['Results of miniaturization'] = '縮略圖結果';
$lang['General statistics'] = '普通統計';
$lang['max time'] = '最多時間';
$lang['average time'] = '平均時間';
$lang['min time'] = '最少時間';
$lang['number of miniaturized photos'] = '創建的縮略圖數';
$lang['total time'] = '總共時間';
$lang['for this file format'] = '對於此文件格式';
$lang['unit mode'] = '單一模式';
$lang['Unlocked'] = '解鎖';
$lang['unset'] = '清空';
$lang['Update albums informations'] = '上傳相冊信息';
$lang['Update photos information'] = '更新圖信息';
$lang['Synchronize'] = '同步';
$lang['reduce to single existing albums'] = '減少現有的單獨相冊';
$lang['Choose an option'] = '選擇一個選項';
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = '顯示最全的信息 (添加相冊和相片，刪除相冊和相片)';
$lang['Piwigo version differs on the remote site'] = '與遠端站點的Piwigo版本不相同';
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = '與遠端站點文件create_listing_file.php版本和Piwigo版本必須相同';
$lang['listing.xml file was not found'] = '沒有發現listing.xml文件';
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = '沒有發現遠端站點listing.xml文件. 可以通過命令"generer le listing" 來產生此文件';
$lang['Error list'] = '錯誤清單';
$lang['Errors caption'] = '錯誤說明';
$lang['Detailed informations'] = '詳細信息';
$lang['File/directory read error'] = '文件/文件夾打開錯誤';
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = '無法打開文件或文件夾(要麼根本不存在,要麼拒絕訪問)';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = '每個圖片文件需要一個縮略圖.縮略圖應該存在於類文件夾下的子文件夾"thumbnail"中. 縮略圖文件名應該以設置參數"prefix_thumbnail"開始, 擴展名為:';
$lang['missing thumbnail'] = '缺少縮略圖';
$lang['albums deleted in the database'] = '相冊已從數據庫刪除';
$lang['photos deleted from the database'] = '圖片已從數據庫中刪除';
$lang['photos candidates for metadata synchronization'] = '對應同步元數據的候選圖片';
$lang['photos informations synchronized with files metadata'] = '附有元數據的同步圖片信息informations des images synchronisees avec les meta-donnees';
$lang['errors during synchronization'] = '同步期間發生錯誤';
$lang['albums added in the database'] = '相冊已添加到數據庫';
$lang['photos added in the database'] = '增加圖片到數據庫';
$lang['photos updated in the database'] = '更新數據庫中的圖片';
$lang['Search for new images in the directories'] = '查詢文件中的新圖片';
$lang['added'] = '已加入';
$lang['deleted'] = '已刪除';
$lang['Metadata synchronization results'] = '元數據更新結果';
$lang['only perform a simulation (no change in database will be made)'] = '只進行模擬操作(不會改變數據庫中的任何內容)';
$lang['[Simulation]'] = '[模擬]';
$lang['Simulation'] = '模擬';
$lang['directories + files'] = '文件夾 + 文件';
$lang['only directories'] = '只對文件夾';
$lang['synchronize files structure with database'] = '同步文件結構和數據庫';
$lang['synchronize files metadata with database photos informations'] = '根據文件元數據同步數據庫中的圖片信息';
$lang['even already synchronized photos'] = '包括已經同步的圖片';
$lang['Used metadata'] = '已使用過的元數據';
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = '文件夾和文件名稱只能包含字母, 數字, "-", "_" 和 "."';
$lang['wrong filename'] = '文件名出錯';
$lang['Upload'] = '增加';
$lang['user "%s" added'] = '用戶 "%s" 已加入';
$lang['User status'] = '用戶狀態';
$lang['user_status_admin'] = '管理員';
$lang['user_status_generic'] = '一般用戶';
$lang['user_status_guest'] = '來賓';
$lang['user_status_normal'] = '遊客';
$lang['user_status_webmaster'] = '網管';
$lang['Virtual album'] = '虛擬相冊';
$lang['Waiting'] = '等待';
$lang['default'] = '默認';
$lang['Toggle \'default group\' property'] = '賦予\'groupe par defaut\'默認組屬性';
$lang['Advanced features'] = '高級功能';
$lang['Specials'] = '特殊';
$lang['Overall'] = '全局視圖';
$lang['Year'] = '年';
$lang['Month'] = '月';
$lang['Day'] = '日';
$lang['Pages seen'] = '已訪問過的頁面';
$lang['Time'] = '時間';
$lang['IP'] = 'IP';
$lang['Element'] = '圖片';
$lang['Section'] = '區域';
$lang['Tags'] = '標籤';
$lang['Save page visits by guests'] = '根據來賓來保存訪問頁面';
$lang['Save page visits by users'] = '根據用戶來保存訪問頁面';
$lang['Save page visits by administrators'] = '根據管理員來保存訪問頁面';
$lang['An information email was sent to group "%s"'] = '已向組 "%s" 的所有成員發送了信息郵件';
$lang['Send an information email to group members'] = '向組成員發送一份信息郵件';
$lang['Group'] = '組';
$lang['[%s] Visit album %s'] = '[%s] 參觀相冊 %s';
$lang['Hello,'] = '你好,';
$lang['See you soon.'] = '再見.';
$lang['Discover album:'] = '探索相冊:';
$lang['Mail content'] = '郵件內容';
$lang['none'] = '沒有任何人';
$lang['high'] = '高';
$lang['other'] = '另外';
$lang['Element type'] = "內容類型";
$lang['Image id'] = '圖片標識符';
$lang['Summary'] = '概述';
$lang['%d line filtered'] = '%d 行被過濾';
$lang['%d lines filtered'] = '%d 行被過濾';
$lang['%d guest'] = '%d 來賓';
$lang['%d guests'] = '%d 來賓';
$lang['Hour'] = '小時';
$lang['guest'] = '來賓';
$lang['default values'] = '默認值';
$lang['High filesize'] = '高清文件大小';
// --------- Starting below: New or revised $lang ---- from version 1.7.1
$lang['Guest cannot be deleted'] = '不能刪除來賓';
$lang['Default user cannot be deleted'] = '不能刪除默認用戶';
$lang['Purge history detail'] = '清除歷史記錄';
$lang['Purge history summary'] = '清除歷史目錄';
$lang['Check integrity'] = '檢測完整性';
$lang['Anomaly'] = '異常';
$lang['Correction'] = '修復';
$lang['Automatic correction'] = '自動修復';
$lang['Impossible automatic correction'] = '無法自動修復';
$lang['Correction applied with success'] = '修復成功';
$lang['Correction applied with error'] = '修復出錯';
$lang['%d anomaly has been detected.'] = '發現了 %d 異常.';
$lang['%d anomalies have been detected.'] = '發現了 %d 個異常.';
$lang['%d anomaly has been corrected.'] = '修正了 %d 異常.';
$lang['%d anomalies have been detected corrected.'] = '修正了 %d 個異常.';
$lang['%d anomaly has not been corrected.'] = '不能修正 %d 異常.';
$lang['%d anomalies have not been corrected.'] = '不能修正 %d 個異常.';
$lang['Go to %s or %s for more informations'] = '獲取更多信息，請到 %s 或者 %s ';
$lang['the forum'] = '論壇';
$lang['the wiki'] = 'wiki';
$lang['%s value is not correct file because exif are not supported'] = ' %s 值不是一個正確文件，因為我們不支持exif格式';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '在配置文件config_local.inc.php中 %s 應該設置為"false"';
$lang['Main "guest" user does not exist'] = '主要"guest"用戶不存在';
$lang['Main "guest" user status is incorrect'] = '主要"guest"用戶狀態異常';
$lang['Default user does not exist'] = '默認帳戶不再存在';
$lang['Main "webmaster" user does not exist'] = '主要網管帳戶不再存在';
$lang['Main "webmaster" user status is incorrect'] = '主要網管用戶狀態異常';
$lang['User "%s" created with "%s" like password'] = '用戶 "%s" 已創建，密碼是"%s"';
$lang['Status of user "%s" updated'] = '用戶 "%s" 狀態已更新';
$lang['add new photos to caddie'] = '把所有新圖片放到購物籃';
// --------- Starting below: New or revised $lang ---- from Butterfly
$lang['No display'] = '不顯示縮略圖';
$lang['Classic display'] = '正常顯示';
$lang['Hoverbox display'] = '俯瞰顯示';
$lang['Mail address is obligatory for all users'] = '每個用戶必須提供郵箱地址';
$lang['Minimum privacy level'] = '最小隱私等級';
$lang['Privacy level'] = '隱私等級';
$lang['Level 0'] = '---';
$lang['Level 1'] = '聯繫';
$lang['Level 2'] = '朋友';
$lang['Level 4'] = '家庭';
$lang['Level 8'] = '管理者';
$lang['Reinitialize check integrity'] = '重新完整性檢測';
$lang['Check all'] = '全選';
$lang['Uncheck all'] = '取消全選';
$lang['Check automatic corrections'] = '自動選擇';
$lang['Apply selected corrections'] = '應用自動選擇';
$lang['Ignore selected anomalies'] = '忽視選擇異常';
$lang['Refresh'] = '刷新';
$lang['The anomaly will be ignored until next application version'] = '此異常將被忽略，待下次版本中解決';
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = '異常更正將取消忽略事件';
$lang['%d anomaly has been ignored.'] = '%d 異常被忽略.';
$lang['%d anomalies have been ignored.'] = '%d 異常被忽略.';
$lang['Plugins which need upgrade'] = '必須更新插件';
$lang['Plugin list'] = '插件列表';
$lang['Check for updates'] = '檢查更新';
$lang['Other plugins'] = '其他插件';
$lang['Last revisions'] = '最新修訂版';
$lang['Delete'] = '刪除';
$lang['Are you sure you want to install this plugin?'] = '確定安裝此插件嗎?';
$lang['Are you sure you want to delete this plugin?'] = '確定要刪除此插件嗎?';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = '確定安裝此更新嗎? 你必須核實無需卸載操作再進行安裝此更新.';
$lang['%s has been successfully upgraded.'] = '%s 成功更新.';
$lang['Plugin has been successfully copied'] = '插件複製成功.';
$lang['You might go to plugin list to install and activate it.'] = '在插件列表中安裝和啟動插件.';
$lang['Can\'t create temporary file.'] = '無法創建臨時文件.';
$lang['Can\'t download archive.'] = '無法下載歸檔文件.';
$lang['Can\'t read or extract archive.'] = '無法讀取或解壓歸檔文件.';
$lang['An error occured during extraction (%s).'] = '在解壓文件(%s) 發生錯誤.';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = '請核實"plugins"文件夾及其子文件夾的權限(CHMOD).';
$lang['Can\'t connect to server.'] = '無法連接到服務器.';
$lang['Purge compiled templates'] = '清除編譯模板';
$lang['Support'] = '支持';
$lang['Documentation'] = '文檔';
$lang['ACCESS_0'] = '自由存取';
$lang['ACCESS_1'] = '對所有人開放';
$lang['ACCESS_2'] = '只對註冊用戶開放';
$lang['ACCESS_3'] = '只對管理員開放';
$lang['ACCESS_4'] = '只對網管開放';
$lang['ACCESS_5'] = '對任何人都不開放';
$lang['A new version of Piwigo is available.'] = 'Piwigo新版發佈.';
$lang['Piwigo Administration'] = 'Piwigo管理';
$lang['Piwigo version'] = 'Piwigo版本';
$lang['You are running the latest version of Piwigo.'] = '你運行的是Piwigo最新版.';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = '%s [%s]安裝版本跟[%s]版本不兼容';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = '為了獲得全部功能，你應該更新系統，否則程序運行不正常。';
$lang['Deleted on'] = '刪除於';
$lang['Last hit'] =  '最後一次查看';
$lang['GD library is missing'] = '缺少GD庫';
$lang['Templates'] = '模板';
$lang['Extend for templates'] = '擴展模板';
$lang['Replacement of original templates by customized templates from template-extension subfolder'] = '用位於template-extension文件夾下的用戶自定義模板更換原模板';
$lang['Replacers (customized templates)'] = '自定義模板';
$lang['Original templates'] = '原模板';
$lang['Optional URL keyword'] = '可選URL關鍵字';
$lang['Templates configuration has been recorded.'] = '模板設置已保存.';
$lang['All optimizations have been successfully completed.'] = '優化成功.';
$lang['Optimizations have been completed with some errors.'] = '有些優化發生錯誤.';
$lang['Modify information'] = '修改信息';
$lang['edit album'] = '修改此相冊的信息';
$lang['nothing'] = '沒有內容';
$lang['overrides existing values with empty ones'] = '用空數據來刪除已存在的數據';
$lang['manage photo ranks'] = '管理圖片排序';
$lang['Manage photo ranks'] = '管理圖片排序';
$lang['Edit ranks'] = '修改排序方式';
$lang['No photo in this album'] = '沒有相片在此相冊裡';
$lang['Images manual order was saved'] = '圖片手動排序已保存';
$lang['ranks'] = '順序';
$lang['Drag to re-order'] = '拖放進行排序';
$lang['Quick Local Synchronization'] = '快速同步';
$lang['No photo can be deleted'] = '沒有圖片可以刪除';
$lang['Delete selected photos'] = '刪除圖片';
$lang['%d photo was deleted'] = '%d 圖片被刪除';
$lang['%d photos were deleted'] = '%d 圖片被刪除';
$lang['Downloads'] = '下載';
$lang['Released on'] = '發佈於';
$lang['Number of downloads'] = '下載次數';
$lang['Operation in progress'] = '正在處理.';
$lang['Please wait...'] = '請稍後...';
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = '訂閱 Piwigo 最新消息，與 Piwigo 項目保持聯繫。當有新版本發佈時，您將會收到郵件通知（有時也包括安全漏洞的修復，這對於升級是很重要的）和項目裡一些重要事情的發生。一年裡也只有幾封郵件。';
$lang['Password is missing. Please enter the password.'] = '密碼沒有輸入，請輸入密碼。';
$lang['Password confirmation is missing. Please confirm the chosen password.'] = '密碼確認未完成，請確認所選定的密碼。';
$lang['Password confirmation error.'] = '請確認錯誤。';
$lang['Allow users to edit their own comments'] = '允許用戶修改自己的評論';
$lang['Allow users to delete their own comments'] = '允許用戶刪除自己的評論';
$lang['Email administrators when a comment is modified'] = '當評論被修改後，發郵件通知管理員';
$lang['Email administrators when a comment is deleted'] = '當評論被刪除後，發郵件通知管理員';
$lang['Cannot delete the old permalink !'] = '舊的固定鏈接不能被刪除!';
$lang['Hit'] = '點擊';
$lang['Tools'] = '工具';
$lang['Photos'] = '相片';
$lang['Themes'] = '主題';
$lang['Instructions to use Piwigo'] = 'Piwigo 使用指南';
$lang['Installed Themes'] = '安裝主題';
$lang['Add New Theme'] = '添加一個新主題';
$lang['Forbid this theme to users'] = '禁用此主題';
$lang['Set as default theme for unregistered and new users'] = '設置為未註冊者和新用戶的默認主題';
$lang['unknown'] = '未知';
$lang['Upload Photos'] = '上傳相片';
$lang['Drop into album'] = '拖進相冊';
$lang['+ Add an upload box'] = '+ 添加一個上傳框';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = '在您的根目錄下創建 "%s" 目錄以完成 Piwigo 的安裝';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = '給予根目錄下的 "%s" 目錄寫權限 (chmod 777) 以完成 Piwigo 的安裝';
$lang['existing album'] = '現有的相冊';
$lang['create a new album'] = '創建一個新相冊';
$lang['Album name'] = '相冊名稱';
$lang['Album "%s" has been added'] = '類別 "%s" 已添加';
$lang['Uploaded Photos'] = '相片已上傳';
$lang['%d photos uploaded'] = '%d 相片已上傳';
$lang['Privacy level set to "%s"'] = '私有級別設置為 "%s"';
$lang['Album "%s" now contains %d photos'] = '類別 "%s" 現已包含了 %d 相片';
$lang['Manage this set of %d photos'] = '管理此設置的 %d 張照片 ';
$lang['Select files'] = '選擇文件';
$lang['Everybody'] = '每個人';
$lang['Who can see these photos?'] = '哪些人可以看到這些相片?';
$lang['The websize maximum width must be a number between %d and %d'] = '最大寬度的網頁尺寸必須在 %d 和 %d 之間';
$lang['The websize maximum height must be a number between %d and %d'] = '最大高度的網頁尺寸必須在 %d 和 %d 之間';
$lang['The websize image quality must be a number between %d and %d'] = '圖片質量的網頁尺寸必須在 %d 和 %d 之間';
$lang['The thumbnail maximum width must be a number between %d and %d'] = '縮略圖的最大寬度必須在 %d 和 %d 之間';
$lang['The thumbnail maximum height must be a number between %d and %d'] = '縮略圖的最大高度必須在 %d 和 %d 之間';
$lang['The thumbnail image quality must be a number between %d and %d'] = '縮略圖的質量必須在 %d 和 %d 之間';
$lang['Settings'] = '設置';
$lang['Web size photo'] = '相片的網頁尺寸';
$lang['Resize'] = '重置大小';
$lang['Maximum Width'] = '最大寬度';
$lang['pixels'] = '像素';
$lang['Maximum Height'] = '最大高度';
$lang['Image Quality'] = '圖片質量';
$lang['Save Settings'] = '保存設置';
$lang['Your configuration settings are saved'] = '你的設置已保存';
$lang['Active Themes'] = '已激活的主題';
$lang['Add write access to the "%s" directory'] = '為 "%s" 目錄添加寫權限';
$lang['Administration Home'] = '管理員首頁';
$lang['Change Admin Colors'] = '更改管理員後台顏色';
$lang['Delete this theme'] = '刪除此主題';
$lang['Directory does not exist'] = '目錄不存在';
$lang['Download,'] = '下載,';
$lang['FTP + Synchronization'] = 'FTP + 同步';
$lang['Get Support on Piwigo Forum'] = '在 Piwigo 論壇上獲取幫助';
$lang['Help Me'] = '幫助我';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = '父主題  %s 丟失，此主題不能被激。';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = '此主題不能刪除，因為其他主題還有依賴與它: %s';
$lang['Inactive Themes'] = '停用主題';
$lang['Install on your computer,'] = '安裝到您的電腦,';
$lang['Make this theme available to users'] = '讓用戶可使用此主題';
$lang['Page end'] = '頁尾';
$lang['Piwigo Uploader'] = 'Piwigo 上傳者';
$lang['Read Piwigo Documentation'] = '閱讀 Piwigo 文檔';
$lang['Start pLoader and add your photos.'] = '開始使用 pLoader 並添加您的相片.';
$lang['Switch to clear or dark colors for administration'] = '更改管理員後台為清爽或者黑暗的顏色';
$lang['Theme has been successfully installed'] = '主題已成功安裝';
$lang['Visit Gallery'] = '瀏覽畫廊';
$lang['Visit Piwigo project website'] = '瀏覽 Piwigo 項目網站';
$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'pLoader 是 <em>Piwigo 上傳者</em> 的官方標準軟件。pLoader 可將您電腦裡的相片傳送到 Piwigo 的相片畫廊裡。';
$lang['Guest Settings'] = '遊客設置';
$lang['Main Page'] = '主頁';
$lang['Photo Page'] = '相片頁';
$lang['Activate Navigation Bar'] = '激活導航條';
$lang['Activate Navigation Thumbnails'] = '激活縮略圖導航';
$lang['Activate icon "%s"'] = '激活圖標 "%s"';
$lang['Activate field "%s"'] = '激活字段 "%s"';
$lang['Photo Properties'] = '相片屬性';
$lang['Allow user customization'] = '允許用戶自定義';
$lang['Languages'] = '語言';
$lang['Installed Languages'] = '安裝語言';
$lang['Add New Language'] = '添加新語言';
$lang['Language has been successfully installed'] = '語言已成功安裝';
$lang['Select:'] = '選擇:';
$lang['None'] = '沒有';
$lang['Invert'] = '反轉';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = '不能停用此主題，您至少需要使用一個主題.';
$lang['Webmaster status is required.'] = '必須設置網站管理員.';
$lang['Bound Theme'] = '綁定主題';
$lang['Allow rating'] = '允許投票';
$lang['Select at least one comment'] = '選擇最新一個評論';
$lang['Active Plugins'] = '激活插件';
$lang['Inactive Plugins'] = '停用插件';
$lang['Missing Plugins'] = '丟失的插件';
$lang['Uninstalled Plugins'] = '未安裝的插件';
$lang['By %s'] = '按 %s';
$lang['Visit plugin site'] = '瀏覽插件網站';
$lang['Active Languages'] = '激活語言';
$lang['Delete this language'] = '刪除此語言';
$lang['Forbid this language to users'] = '禁止用戶使用此語言';
$lang['Impossible to deactivate this language, first set another language as default.'] = '不能停用此語言，請先設置一個默認語言.';
$lang['Impossible to deactivate this language, you need at least one language.'] = '不能停用此語言，您必須至少使用一個語言.';
$lang['Inactive Languages'] = '停用語言';
$lang['Make this language available to users'] = '讓用戶可使用此語言';
$lang['Set as default language for unregistered and new users'] = '設置為遊客和新用戶的默認語言';
$lang['Add Photos'] = '添加相片';
$lang['Download'] = '下載';
$lang['The following tag was deleted'] = '以下標籤已刪除';
$lang['Miscellaneous'] = '雜項';
$lang['Virtual Links'] = '虛擬鏈接';
$lang['There is no other language available.'] = '沒有其他可用的語言.';
$lang['There is no other plugin available.'] = '沒有其他可用的插件.';
$lang['There is no other theme available.'] = '沒有其他可用的主題.';
$lang['Add another set of photos'] = '添加另一組相片';
$lang['By rank'] = '按等級';
$lang['Manual order'] = '手工排序';
$lang['Piwigo Announcements Newsletter'] = 'Piwigo最新消息公告';
$lang['Subscribe %s'] = '訂閱%s';
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = '訂閱%s Piwigo中國最新消息公告';
$lang['Purge search history'] = '清除查尋歷史記錄';
$lang['Hide'] = '隱藏';
$lang['Order of menubar items has been updated successfully.'] = '所有項目已被更新.';
$lang['This theme was not designed to be directly activated'] = '此主題並未設計為直接激活';
$lang['Who can see this photo?'] = '有哪些人能看這些相片?';
$lang['Pending Comments'] = '待批的評論';
$lang['Menu Management'] = '菜單';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = '在你的 php.ini 文件, 如果 upload_max_filesize (%sB) 大於 post_max_size (%sB), 那麼你需要修改此項';
$lang['Exif extension not available, admin should disable exif use'] = 'Exif 擴展不能使用，管理員應該禁用 exif 功能。';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = '上傳文件超過了在 php.ini 文件裡的 upload_max_filesize 限制: %sB';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = '上傳文件超過了在 php.ini 文件裡的 post_max_size 限制: %sB';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = '上傳文件超過了在 HTML 表單指定的 MAX_FILE_SIZE 的限制';
$lang['The uploaded file was only partially uploaded'] = '上傳文件只上傳了一部分';
$lang['No file was uploaded'] = '沒有文件被上傳';
$lang['Missing a temporary folder'] = '缺少臨時文件目錄';
$lang['Failed to write file to disk'] = '文件寫入失敗';
$lang['File upload stopped by extension'] = '擴展使文件上傳停止';
$lang['Unknown upload error'] = '未知上傳錯誤';
$lang['Error on file "%s" : %s'] = '文件上的錯誤 "%s" : %s';
$lang['%d of %d photos selected'] = '%d 張/總 %d 相片被選中';
$lang['Action'] = '動作';
$lang['Add a filter'] = '添加一個過濾器';
$lang['Album photos associated to the following albums: %s'] = '相片已關聯到以下相冊: %s';
$lang['Albums automatically sorted'] = '相冊已自動排序';
$lang['All %d photos are selected'] = '全部 %d 張相片已選中';
$lang['Apply action'] = '應用動作';
$lang['automatic order'] = '自動排序';
$lang['Batch Manager'] = '批量管理';
$lang['Choose an action'] = '選擇一個動作';
$lang['Delete orphan tags'] = '刪除沒被關聯的標籤';
$lang['delete photo'] = '刪除相片';
$lang['duplicates'] = '重複';
$lang['include child albums'] = '包含子相冊';
$lang['Keep high definition'] = '保留高清晰度';
$lang['last import'] = '最後導入';
$lang['manual order'] = '手工排序';
$lang['No photo in the current set.'] = '當前集合沒有相片.';
$lang['No photo selected, %d photos in current set'] = '沒有選擇相片, 當前集合有 %d 張相片';
$lang['No photo selected, no action possible.'] = '沒有選擇相片，不會有動作執行.';
$lang['on the %d selected photos'] = '在 %d 張已選相片上';
$lang['Orphan tags deleted'] = '無關聯標籤已被刪除';
$lang['predefined filter'] = '預定義的過濾器';
$lang['Refresh photo set'] = '刷新相片集';
$lang['Remove all filters'] = '刪除所有過濾器';
$lang['remove author'] = '刪除作者';
$lang['remove creation date'] = '刪除創建日期';
$lang['remove this filter'] = '刪除此過濾器';
$lang['remove title'] = '刪除標題';
$lang['Selection'] = '選擇';
$lang['Set author'] = '設置作者';
$lang['Set creation date'] = '設置創建日期';
$lang['Set title'] = '設置標題';
$lang['The high definition image quality must be a number between %d and %d'] = '高清晰度相片質量必須在 %d 和 %d 之間';
$lang['The high definition maximum height must be a number between %d and %d'] = '高清晰度相片最大高度必須在 %d 和 %d 之間';
$lang['The high definition maximum width must be a number between %d and %d'] = '高清晰度相片最大寬度必須在 %d 和 %d 之間';
$lang['The whole page'] = '整張相片';
$lang['The whole set'] = '整個集合';
$lang['Type here the author name'] = '在此輸入作者名稱';
$lang['Type here the title'] = '在此輸入標題';
$lang['Week starts on'] = '星期起始於';
$lang['with no album'] = '沒有相冊';
$lang['with no tag'] = '沒有標籤';
$lang['with no virtual album'] = '沒有虛擬相冊';
$lang['You have %d orphan tags: %s.'] = '您已 %d 無關聯標籤: %s.';
$lang['Remove from caddie'] = '從購物藍裡移除';
$lang['Themes which need upgrade'] = '需更新的主題';
$lang['Languages which need upgrade'] = '需更新的語言';
$lang['All themes are up to date.'] = '所有主題都是最新的';
$lang['All plugins are up to date.'] = '所有插件都是最新的';
$lang['All languages are up to date.'] = '所有語言都是最新的';
$lang['Visit theme site'] = '瀏覽主題頁面';
$lang['Visit language site'] = '瀏覽語言頁面';
$lang['New Version'] = '新版本';
$lang['new'] = '新增';
$lang['No results'] = '沒有結果';
$lang['Searching...'] = '搜尋中...';
$lang['Type in a search term'] = '輸入搜索字詞';
$lang['Obsolete Plugins'] = '過時(廢棄)的插件';
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = '警告! 這個插件與此Piwigo版本不相容!';
$lang['Do you want to activate anyway?'] = '你無論如何都要啟動嗎?';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = '這個插件目前是Piwigo核心一部份! 請立即移除它!';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = '錯誤：這個插件雖已安裝但並不存在! 請立即移除它!';
$lang['display'] = '顯示'; 
$lang['Learn more'] = '瞭解更多';
$lang['Rate'] = '評分';
$lang['Average rate'] = '評分';
$lang['Activate icon "new" next to albums and pictures'] = '在相簿及相片旁邊加上"新"的圖示';
$lang['Add a criteria'] = '新增標準';
$lang['Deactivate all'] = '取消全部';
$lang['Default photos order'] = '預設的相片順序';
$lang['Restore'] = '復原';
$lang['Restore default configuration. You will lose your plugin settings!'] = '復原至預設設定。你將失去你在套件上的設定！';
$lang['Show menubar'] = '顯示選單列';
$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = '無法使用預設相片順序，因你在本地端已另有設定。';
$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = '你已在本地設定檔選用 <i>$conf[\'order_by\']</i>，造成參數矛盾，請將它移除或重新命名為 <i>$conf[\'order_by_custom\']</i>！';
$lang['Regenerate Thumbnails'] = '重新製作小圖';
$lang['Regenerate Websize Photos'] = '重新製作適用於網頁瀏覽的圖片';
$lang['Thumbnails generation in progress...'] = '小圖製作中...';
$lang['Photos generation in progress...'] = '圖片製作中...';
$lang['%s thumbnails have been regenerated'] = '小圖製作完成';
$lang['%s thumbnails can not be regenerated'] = '無法製作小圖';
$lang['%s photos have been regenerated'] = '%s圖片製作完成';
$lang['%s photos can not be regenerated'] = '無法製作%s圖片';
?>